%global __provides_exclude perl\\(.*\\)
%global __requires_exclude perl\\((Sympa.*|Archive|Auth|Bounce|Bulk|Commands|Conf|Config_XML|Datasource|Family|Fetch|Language|Ldap|List|Lock|Log|Marc.*|Message|PlainDigest|Robot|SDM|SharedDocument|Scenario|SQLSource|Task|Upgrade|WebAgent|admin|confdef|mail|report|tools|tt2|wwslib)\\)
%global __requires_exclude %{?__requires_exclude}|^perl\\((cookielib|sympasoap|time_utils)\\)

Name:		sympa
Version:	6.2.42
%define		subrel 1
Release:	%mkrel 1
Summary:	Electronic mailing list manager
License:	GPL
Group:		System/Servers
URL:		http://www.sympa.org/
Source0:	http://www.sympa.org/distribution/%{name}-%{version}.tar.gz
Source6:	sympa.tmpfiles
# CVE-2020-9369
Patch0:		sympa-6.2.52-sa-2020-001.patch
Requires:	openssl >= 0.9.5a
Requires:	mhonarc >= 2.4.5
Requires:   mail-server
Requires:   sympa-database
Recommends: perl-Mail-DKIM
Requires(pre):	    rpm-helper
Requires(post):     rpm-helper >= 0.20.0
Requires(post):     mail-server
Requires(preun):    rpm-helper
Requires(preun):    mail-server
Requires(postun):   rpm-helper >= 0.16
BuildRequires:      rpm-helper >= 0.20.0
BuildRequires:      rpm-mageia-setup
BuildRequires:	    pkgconfig(openssl)
BuildRequires:	    perl-Class-Singleton
BuildRequires:	    perl-DateTime
BuildRequires:	    perl-DBI
BuildRequires:	    perl-File-Copy-Recursive
BuildRequires:	    perl-HTML-Parser
BuildRequires:	    perl-MailTools
BuildRequires:	    perl-MIME-EncWords
BuildRequires:	    perl-Unicode-LineBreak
BuildRequires:	    perl-URI
BuildRequires:	    perl-libintl-perl
BuildRequires:	    gettext-devel

%description
Sympa is an open source mailing list manager. It provides advanced features with a rich and secure web interface.

%package www
Summary:	Web interface for Sympa
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	webserver
Recommends:   apache-mod_fastcgi
Recommends:   perl(CGI::Fast)
Recommends:   perl(FCGI)
Requires(post):     rpm-helper >= 0.20.0
Requires(postun):   rpm-helper >= 0.16

%description www
This package contains the web interface for %{name}.

%package mysql
Summary:    MySQL database support for Sympa
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
Requires:   perl-DBD-mysql

%description mysql
This package ensures the necessary dependencies are in place for Sympa to
work with MySQL / MariaDB databases. It does not require a MySQL / MariaDB
server to be installed, as you may well wish to use a remote database
server.

%package postgresql
Summary:    PostgreSQL database support for Sympa
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
Requires:   perl-DBD-Pg

%description postgresql
This package ensures the necessary dependencies are in place for Sympa to
work with a PostgreSQL database. It does not require the PostgreSQL server
package to be installed, as you may well wish to use a remote database
server.

%prep
%setup -q 
%patch0 -p1

%build
%serverbuild
%configure2_5x \
    --enable-fhs \
    --libexecdir=%{_sbindir} \
    --sysconfdir=%{_sysconfdir}/sympa \
    --with-unitsdir=%{_unitdir} \
    --with-confdir=%{_sysconfdir}/sympa \
    --with-aliases_file=%{_localstatedir}/lib/sympa/aliases \
    --with-newaliases_arg=-oA/var/lib/sympa/aliases
%make

%install
%makeinstall_std HOST=localhost < /dev/null

perl -pi -e 's|/var/run|/run|' \
    %{buildroot}%{_sysconfdir}/sympa/sympa.conf

rm -f %{buildroot}%{_sysconfdir}/sympa/rc.d/init.d/sympa
install -D -m 644 %{SOURCE6} %{buildroot}%{_prefix}/lib/tmpfiles.d/sympa.conf

install -d -m 755 %{buildroot}%{_unitdir}/sympa.service.d

cat > %{buildroot}%{_unitdir}/sympa.service.d/mysql.conf <<EOF
[Unit]
After=mysqld.service
EOF

cat > %{buildroot}%{_unitdir}/sympa.service.d/postgresql.conf <<EOF
[Unit]
After=postgresql.service
EOF

# apache conf
install -d -m 755 %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/sympa.conf <<EOF
Alias /static-sympa %{_localstatedir}/lib/sympa/static_content
Alias /sympa %{_libdir}/sympa/cgi

<Directory %{_localstatedir}/lib/sympa/static_content>
    Require all granted
</Directory>

<Directory %{_libdir}/sympa/cgi>
    Options ExecCGI
    # fallback handler if mod_fcgid is not installed
    <IfModule !mod_fcgid.c>
        AddHandler cgi-script .fcgi
    </IfModule>
    DirectoryIndex wwsympa-wrapper.fcgi
    Require all granted
</Directory>
EOF

# no need for perl modules man pages
rm -rf %{buildroot}%{_mandir}/man3

# Install remaining documentation manually
install -m 644 AUTHORS.md COPYING NEWS.md README.md %{buildroot}%{_docdir}/%{name}

# don't install  bundled certs
rm -f %{buildroot}%{_datadir}/sympa/ca-bundle.crt

# not the place for documentation
rm -f %{buildroot}%{_sysconfdir}/sympa/README

# drop sendmail stuff
rm -rf %{buildroot}%{_sysconfdir}/sympa/smrsh

%find_lang sympa
%find_lang web_help
cat web_help.lang >> sympa.lang

%pre
%_pre_useradd sympa %{_localstatedir}/lib/sympa /bin/false

%post
%_post_service sympa

if [ $1 = 1 ]; then
  # installation

  # sympa configuration
  hostname=`hostname`

  perl -pi \
    -e "s|^domain(\s+).*|domain\$1$hostname|;" \
    -e "s|^listmaster(\s+).*|listmaster\$1listmaster\@$hostname|;" \
    -e "s|^wwsympa_url(\s+).*|wwsympa_url\$1http://$hostname/sympa|;" \
    -e "s|^syslog(\s+).*|syslog\$1mail|;" \
    %{_sysconfdir}/sympa/sympa.conf

  # Initial aliase file creation
  cat >> %{_localstatedir}/lib/sympa/aliases <<EOF
listmaster:	"|%{_sbindir}/queue listmaster"
sympa:		"|%{_sbindir}/queue sympa"
bounce+*:	"|%{_sbindir}/bouncequeue sympa"
sympa-request:	listmaster@$hostname
sympa-owner:	listmaster@$hostname
EOF
  chown sympa.sympa %{_localstatedir}/lib/sympa/aliases

  # mta-specific aliases inclusion procedure
  mta="`readlink /etc/alternatives/sendmail-command 2>/dev/null | cut -d . -f 2`"
  if [ "$mta" == "postfix" ]; then
    database=`/usr/sbin/postconf -h alias_database`
    maps=`/usr/sbin/postconf -h alias_maps`
    postconf -e \
        "alias_database = $database, hash:%{_localstatedir}/lib/sympa/aliases" \
        "alias_maps = $maps, hash:%{_localstatedir}/lib/sympa/aliases"
  else
    cat >> %{_sysconfdir}/aliases <<EOF
:include:	%{_localstatedir}/lib/sympa/aliases
EOF
  fi
  # masqmail don't have this command
  [ -x /usr/bin/newaliases ] && /usr/bin/newaliases
else
  # find aliases file
  aliases=`awk '/sendmail_aliases/ {print $2}' %{_sysconfdir}/sympa/sympa.conf`
  if [ -z "$aliases" ]; then
    aliases=%{_sysconfdir}/aliases
  fi
  # correct pathes
  sed -i \
      -e 's|%{_bindir}/queue|%{_sbindir}/queue|' \
      -e 's|%{_bindir}/bouncequeue|%{_sbindir}/bouncequeue|' \
      $aliases
  # regenerate aliases
  /usr/bin/newaliases
fi

%preun
%_preun_service sympa

if [ $1 = 0 ]; then
  # uninstallation

  # remove aliases
  mta="`readlink /etc/alternatives/sendmail-command 2>/dev/null | cut -d . -f 2`"
  if [ "$mta" == "postfix" ]; then
    database=`/usr/sbin/postconf -h alias_database | \
      sed -e 's|, hash:%{_localstatedir}/lib/sympa/aliases||'`
    maps=`/usr/sbin/postconf -h alias_maps | \
      sed -e 's|, hash:%{_localstatedir}/lib/sympa/aliases||'`
    postconf -e \
      "alias_database = $database" \
      "alias_maps = $maps"
  else
    sed -i -e '/:include:   %{_localstatedir}/lib/sympa/aliases/d' \
      %{_sysconfdir}/aliases
  fi
  /usr/bin/newaliases
fi

%postun
%_postun_userdel sympa

%files -f sympa.lang
%{_docdir}/%{name}

# variable directories
%attr(-,sympa,sympa) %{_localstatedir}/lib/sympa
%attr(-,sympa,sympa) %{_localstatedir}/spool/sympa

# config files
%dir %{_sysconfdir}/sympa
%config(noreplace) %attr(640,root,sympa) %{_sysconfdir}/sympa/sympa.conf
%config(noreplace) %{_sysconfdir}/sympa/data_structure.version

%{_unitdir}/sympa.service
%{_unitdir}/sympa-outgoing.service
%{_unitdir}/sympa-archive.service
%{_unitdir}/sympa-bounce.service
%{_unitdir}/sympa-task.service
%{_prefix}/lib/tmpfiles.d/sympa.conf

# binaries
%attr(-,sympa,sympa) %{_sbindir}/queue
%attr(-,sympa,sympa) %{_sbindir}/bouncequeue
%attr(-,sympa,sympa) %{_sbindir}/familyqueue
%attr(-,sympa,sympa) %{_sbindir}/sympa_newaliases.pl
%attr(-,root,sympa) %{_sbindir}/sympa_newaliases-wrapper
%{_sbindir}/sympa.pl
%{_sbindir}/sympa_msg.pl
%{_sbindir}/sympa_automatic.pl
%{_sbindir}/sympa_wizard.pl
%{_sbindir}/alias_manager.pl
%{_sbindir}/archived.pl
%{_sbindir}/bounced.pl
%{_sbindir}/bulk.pl
%{_sbindir}/task_manager.pl

# other
%{_datadir}/sympa
%{_mandir}/man1/*
%{_mandir}/man8/*
%{_mandir}/man5/*

%files www
%dir %{_libdir}/sympa
%dir %{_libdir}/sympa/cgi
%{_libdir}/sympa/cgi/wwsympa.fcgi
%{_libdir}/sympa/cgi/sympa_soap_server.fcgi
%attr(-,sympa,sympa) %{_libdir}/sympa/cgi/sympa_soap_server-wrapper.fcgi
%attr(-,sympa,sympa) %{_libdir}/sympa/cgi/wwsympa-wrapper.fcgi
%config(noreplace) %{_webappconfdir}/sympa.conf

%files mysql
%{_unitdir}/sympa.service.d/mysql.conf

%files postgresql
%{_unitdir}/sympa.service.d/postgresql.conf


%changelog
* Thu Mar 05 2020 tmb <tmb> 6.2.42-1.1.mga7
+ Revision: 1554178
- fix sa-2020-001 (CVE-2020-9369)

* Sun Apr 21 2019 tmb <tmb> 6.2.42-1.mga7
+ Revision: 1394488
- update to 6.2.42

* Mon Feb 11 2019 tmb <tmb> 6.2.40-1.mga7
+ Revision: 1365270
- update to 6.2.40

* Sat Oct 20 2018 tmb <tmb> 6.2.36-1.mga7
+ Revision: 1323033
- BR: perl-File-Copy-Recursive
- BR: perl-Unicode-LineBreak
- BR: perl-HTML-Parser
- BR: perl-DBI
- BR: perl-URI
- BR: perl-DateTime
- update to 6.2.36 (CVE-2018-1000671)
- BR: perl-MIME-EncWords

* Sun Sep 23 2018 umeabot <umeabot> 6.2.32-2.mga7
+ Revision: 1301272
- Mageia 7 Mass Rebuild

* Tue Jun 12 2018 tmb <tmb> 6.2.32-1.mga7
+ Revision: 1236492
- update to 6.2.32

* Fri Mar 30 2018 tmb <tmb> 6.2.30-1.mga7
+ Revision: 1213673
- update to 6.2.30

* Mon Feb 26 2018 tmb <tmb> 6.2.24-1.mga7
+ Revision: 1205251
- BR: perl-Class-Singleton
- update to 6.2.24
- update filelists

* Sun Sep 17 2017 guillomovitch <guillomovitch> 6.2.18-1.mga7
+ Revision: 1155091
- new version 6.2.18
- recommends perl-Mail-DKIM for DKIM support
- add sympa-database packages for managing database-specific dependencies and service ordering

* Fri Jun 24 2016 guillomovitch <guillomovitch> 6.2.16-1.mga6
+ Revision: 1037463
- new version 6.2.16

* Thu Jun 23 2016 guillomovitch <guillomovitch> 6.2.15-1.mga6
+ Revision: 1037362
- new version 6.2.15
- use upstream systemd files
- drop obsolete mageia-specific README.urpmi file

* Sun Dec 13 2015 guillomovitch <guillomovitch> 6.2.12-1.mga6
+ Revision: 910238
- new version 6.2.12

* Wed Nov 04 2015 guillomovitch <guillomovitch> 6.2.9-2.mga6
+ Revision: 897791
- fix automatic dependencies

* Wed Oct 21 2015 guillomovitch <guillomovitch> 6.2.9-1.mga6
+ Revision: 893989
- new version 6.2.9

* Tue Feb 17 2015 guillomovitch <guillomovitch> 6.1.24-3.mga5
+ Revision: 815409
- add a soft dependency on FCGI perl module (#15097)

* Sat Jan 31 2015 guillomovitch <guillomovitch> 6.1.24-2.mga5
+ Revision: 812857
- only provide a fallback handler for wwsympa.fcgi if mod_fcgid is not installed, in default apache configuration

* Fri Jan 23 2015 guillomovitch <guillomovitch> 6.1.24-1.mga5
+ Revision: 811961
- new version

* Wed Oct 15 2014 umeabot <umeabot> 6.1.23-3.mga5
+ Revision: 743506
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 6.1.23-2.mga5
+ Revision: 732792
- add exclude

* Fri Sep 26 2014 guillomovitch <guillomovitch> 6.1.23-1.mga5
+ Revision: 724869
- new version 6.1.23
- fix automatic dependencies

* Tue Sep 16 2014 umeabot <umeabot> 6.1.22-2.mga5
+ Revision: 689651
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Fri Jun 13 2014 guillomovitch <guillomovitch> 6.1.22-1.mga5
+ Revision: 636025
- new version 6.1.22
- new version

* Mon Oct 21 2013 luigiwalser <luigiwalser> 6.1.17-3.mga4
+ Revision: 540836
- fix pod2man errors due to non-ascii chars with no encoding set
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ guillomovitch <guillomovitch>
- define newaliases arg at build time, to ensure correct alias update

* Wed Feb 06 2013 guillomovitch <guillomovitch> 6.1.17-1.mga3
+ Revision: 394785
- new version

* Mon Jan 14 2013 umeabot <umeabot> 6.1.16-2.mga3
+ Revision: 383886
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Nov 17 2012 guillomovitch <guillomovitch> 6.1.16-1.mga3
+ Revision: 319138
- new version

* Sat Oct 06 2012 guillomovitch <guillomovitch> 6.1.15-1.mga3
+ Revision: 303060
- new version

* Fri Sep 14 2012 guillomovitch <guillomovitch> 6.1.14-1.mga3
+ Revision: 293844
- new version

* Fri Aug 24 2012 guillomovitch <guillomovitch> 6.1.11-5.mga3
+ Revision: 283663
- make webapp configuration file compliant with apache 2.4

* Sat Aug 04 2012 guillomovitch <guillomovitch> 6.1.11-4.mga3
+ Revision: 278467
- fix path in apache configuration file (#6772)

* Tue Jul 10 2012 guillomovitch <guillomovitch> 6.1.11-2.mga3
+ Revision: 269257
- add systemd support
- drop sysinit support
- add soft dependency on perl-CGI-Fast
- update README.urpmi, as db schema files location changed
- mention the need of proper DBD driver package
- new version

* Tue May 08 2012 pterjan <pterjan> 6.1.9-2.mga2
+ Revision: 234918
- Fix initscript's LSB header

* Tue Mar 27 2012 guillomovitch <guillomovitch> 6.1.9-1.mga2
+ Revision: 227182
- new version

* Wed Dec 07 2011 guillomovitch <guillomovitch> 6.1.7-1.mga2
+ Revision: 178321
- new version

* Mon Sep 26 2011 dmorgan <dmorgan> 6.1.5-2.mga2
+ Revision: 147873
- Fix deps in rpm-mageia-setup

* Sun Jun 19 2011 kharec <kharec> 6.1.5-1.mga2
+ Revision: 109677
- new version 6.1.5

* Sun May 15 2011 pterjan <pterjan> 6.1.4-2.mga1
+ Revision: 98970
- Rebuild for fixed find-requires

* Mon Apr 18 2011 misc <misc> 6.1.4-1.mga1
+ Revision: 87648
- remove version check, as all recents versions are ok
- update sympa to 6.1.4

* Sun Mar 06 2011 ennael <ennael> 6.1.3-1.mga1
+ Revision: 65703
- clean spec file
+ kharec <kharec>
- imported package sympa

